# solitaire-game

Solitaire game (klondike), made with python & curses. Play in the terminal. For Linux, Mac OS and Windows.


![](doc/screenshot.png)

## How to install

```shell
$ pip install solitaire-game
```

## How to play

```shell
$ solitaire
```

## Technical documentation

![](doc/doc_game.png)
